@@ -1783,10 +1783,11 @@ static void failover(void)
 			{
 				/* only if the failover is against the current primary */
 				if (((reqkind == NODE_DOWN_REQUEST) &&
+					 Req_info->primary_node_id >= 0 &&
 					 (nodes[Req_info->primary_node_id])) ||
-					((reqkind == PROMOTE_NODE_REQUEST) &&
-					 (VALID_BACKEND(node_id)))) {
-
+					(node_id >= 0 && (reqkind == PROMOTE_NODE_REQUEST) &&
+					 (VALID_BACKEND(node_id))))
+				{
 					for (i = 0; i < pool_config->backend_desc->num_backends; i++)
 					{
 						/* do not degenerate the new primary */
